@@ -32,7 +32,6 @@ import hubzero.utilities.misc
 import hubzero.config.webconfig
 import hubzero.data.db
 import ldap
-import ldap.modlist
 import os
 
 
@@ -41,27 +40,36 @@ def userExists(username):
 	dbUserName = hubzero.config.webconfig.getWebConfigDBUsername()
 	dbName = hubzero.config.webconfig.getWebConfigDBName()
 	
-	db =  hubzero.data.db.mySql("localhost", dbName, dbUserName, dbPW)
-	rv = _userExists(db, username)
-	return rv
+	db =  hubzero.data.db.MySQLConnection("localhost", dbName, dbUserName, dbPW)
+	if _userExists(db, username):
+		return True
+	else:
+		return False
+	
 
 def _userExists(db, username):
 	sql = 'select id from `jos_users` where username = %s'
 	data = (username)
-
-	userID = db.execSelectQueryScalar(sql, data)
+	userID = db.query_selectscalar(sql, data)
 	
-	if userID is None:
-		return False
-	else:
-		return True
+	return userID
 
 
+def userLookup(username):
+	dbPW = hubzero.config.webconfig.getWebConfigDBPassword()
+	dbUserName = hubzero.config.webconfig.getWebConfigDBUsername()
+	dbName = hubzero.config.webconfig.getWebConfigDBName()
+	
+	db =  hubzero.data.db.MySQLConnection("localhost", dbName, dbUserName, dbPW)
+	rv = _userExists(db, username)
+	return rv
+	
+
 def _getUserID(db, username):
 	sql = 'select id from `jos_users` where username = %s'
 	data = (username)
 
-	userID = db.execSelectQueryScalar(sql, data)
+	userID = db.query_selectscalar(sql, data)
 	
 	if userID is None:
 		return None
@@ -72,11 +80,11 @@ def _getUserID(db, username):
 def _del_jos_users(db, username):
 	sql = 'select id from `jos_users` where username = %s'
 	data = (username)
-	userID = db.execSelectQueryScalar(sql, data)	
+	userID = db.query_selectscalar(sql, data)	
 
 	sql = 'delete from `jos_users` where userid = %s'
 	data = (userID)
-	userID = db.execSelectQueryScalar(sql, data)	
+	userID = db.query_selectscalar(sql, data)	
 
 	return userID
 
@@ -85,11 +93,11 @@ def _del_jos_core_acl_aro(db, userID):
 
 	sql = 'select id from `jos_core_acl_aro` where `value` = %s'
 	data = (userID)
-	aroID = db.execSelectQueryScalar(sql, data)	
+	aroID = db.query_selectscalar(sql, data)	
 
 	sql = "DELETE FROM `jos_core_acl_aro` where `value` = %s"
 	data = (userID)
-	db.execQuery(sql, data)
+	db.query_rowcount(sql, data)
 	
 	return aroID
 
@@ -98,25 +106,25 @@ def _del_jos_core_acl_groups_aro_map(db, aroID):
 	print "aroID = " + str(aroID)
 	sql = "DELETE FROM `jos_core_acl_groups_aro_map` WHERE `aro_id` = %s"
 	data = (aroID)
-	db.execQuery(sql, data)
+	db.query_rowcount(sql, data)
 
 
 def _del_jos_xprofiles(db, uidNumber):
 	sql = "DELETE FROM `jos_xprofiles` WHERE `uidNumber` = %s"
 	data = (uidNumber)
-	db.execQuery(sql, data)
+	db.query_rowcount(sql, data)
 
 
 def _update_jos_profiles_pw(db, userid, pwHash):
 	sql = "UPDATE `jos_xprofiles` SET `userPassword`=%s WHERE `uidNumber`=%s"
 	data = (pwHash, userid)
-	db.execQuery(sql, data)
+	db.query_rowcount(sql, data)
 
 
 def _update_jos_users_pw(db, userid, pwHash):
 	sql = "UPDATE `jos_users` SET `password` = %s WHERE `id`=%s"
 	data = (pwHash, userid)
-	db.execQuery(sql, data)
+	db.query_rowcount(sql, data)
 	
 	
 
@@ -134,7 +142,7 @@ def _update_ldap_user_pw(username, uidNumber, pw):
 
 	dn = "uid=" + username + ",ou=users," + hubLDAPBaseDN
 	
-	print "dn>>>" + dn
+	print "dn=" + dn
 
 	if pw != '*':
 		attrs = [ (ldap.MOD_REPLACE, 'userPassword', hubzero.config.passwords.MD5PasswordHash(pw)) ]
@@ -154,12 +162,12 @@ def _insert_jos_users(db, joomlauserid, name, username, email, pw, jgid, jgidNum
 		sql = "INSERT INTO `jos_users` (`name`, `username`, `email`, `password`, `usertype`, `block`, `sendEmail`, `gid`, `registerDate`, `lastvisitDate`, `activation`, `params`)"
 		sql += "VALUES (%s, %s, %s, %s, %s, %s, %s, %s, %s, %s, %s, %s);"
 		data = (name, username, email, pwhash , jgid, 0, 1, jgidNumber, datetime.datetime.now(), '0000-00-00 00:00:00', '', '');
-		userID = db.execInsertQuery(sql, data)
+		userID = db.query_lastrowid(sql, data)
 	else:
 		sql = "INSERT INTO `jos_users` (`id`, `name`, `username`, `email`, `password`, `usertype`, `block`, `sendEmail`, `gid`, `registerDate`, `lastvisitDate`, `activation`, `params`)"
 		sql += "VALUES (%s, %s, %s, %s, %s, %s, %s, %s, %s, %s, %s, %s, %s);"
 		data = (joomlauserid, name, username, email, pwhash, jgid, 0, 1, jgidNumber, datetime.datetime.now(), '0000-00-00 00:00:00', '', '');
-		userID = db.execInsertQuery(sql, data)
+		userID = db.query_lastrowid(sql, data)
 
 	return userID
 
@@ -168,7 +176,7 @@ def _insert_jos_core_acl_aro(db, userID, fullname):
 	sql = "INSERT INTO `jos_core_acl_aro` (`section_value`, `value`, `order_value`, `name`, `hidden`) "
 	sql += "VALUES (%s, %s, %s, %s, %s)"
 	data = ( 'users',  userID, 0, fullname, 0)
-	aroID = db.execInsertQuery(sql, data)
+	aroID = db.query_lastrowid(sql, data)
 	return aroID
 	
 
@@ -176,7 +184,7 @@ def _insert_jos_core_acl_groups_aro_map(db, jgidNumber, aroID):
 	sql = "INSERT INTO `jos_core_acl_groups_aro_map` (`group_id`, `section_value`, `aro_id`) "
 	sql += "VALUES (%s, %s, %s)"
 	data = ( jgidNumber, '', aroID)
-	db.execQuery(sql, data)
+	db.query_rowcount(sql, data)
 
 def _insert_jos_xprofiles(db, hubname, uid, fname, mname, lname, username, email, pw, joomlagid, joomlagidNumber, gid, gidNumber, loginShell, homeDir):
 	
@@ -190,7 +198,7 @@ def _insert_jos_xprofiles(db, hubname, uid, fname, mname, lname, username, email
 	        '/usr/lib/sftp-server', hubzero.config.passwords.MD5PasswordHash(pw), gid, '', '', '', '', '', '', '', 
 	        0, 0, 3, '0000-00-00 00:00:00', 1, '', '', '', '',
 	        '', '', fname, mname, lname, '', 0, 0, '', '', None)
-	db.execQuery(sql, data)
+	db.query_rowcount(sql, data)
 
 
 def _insert_jos_users_password(db, userid, pw):
@@ -198,10 +206,10 @@ def _insert_jos_users_password(db, userid, pw):
 	sql += "VALUES (%s, %s)"
 	
 	data = (userid, hubzero.config.passwords.MD5PasswordHash(pw))
-	db.execQuery(sql, data)
+	db.query_rowcount(sql, data)
 
 
-def _add_ldap_user(username, gecos, password, uidNumber, homeDir, loginShell, gid, gidNumber):
+def add_ldap_user(username, gecos, password, uidNumber, homeDir, loginShell, gid, gidNumber):
 
 	# get ldapManagerUserDN and PW
 	
@@ -219,6 +227,8 @@ def _add_ldap_user(username, gecos, password, uidNumber, homeDir, loginShell, gi
 
 	if password != '*':
 		attrs['userPassword'] = hubzero.config.passwords.MD5PasswordHash(password)
+	elif '{MD5}' in password:
+		attrs['userPassword'] = password
 	else:
 		attrs['userPassword'] = '{MD5}*' # can user generate a value that will MD5 hash to '*'?
 	
@@ -238,7 +248,7 @@ def _add_ldap_user(username, gecos, password, uidNumber, homeDir, loginShell, gi
 	l.add_s(dn, ldif)
 
 
-def _delete_ldap_user(username):
+def delete_ldap_user(username):
 	# get ldapManagerUserDN and PW
 	hubLDAPAcctMgrDN = hubzero.config.webconfig.getComponentParam("com_system", "ldap_managerdn")
 	hubLDAPAcctMgrPW= hubzero.config.webconfig.getComponentParam("com_system", "ldap_managerpw")
@@ -260,7 +270,7 @@ def addhubuser(hubname, username, gecos, email, pw, pwdisabled, joomlagid,
 	dbUserName = hubzero.config.webconfig.getWebConfigDBUsername()
 	dbName = hubzero.config.webconfig.getWebConfigDBName()
 	
-	db =  hubzero.data.db.mySql("localhost", dbName, dbUserName, dbPW)
+	db =  hubzero.data.db.MySQLConnection("localhost", dbName, dbUserName, dbPW)
 
 	if _userExists(db, username):
 		print "User already exists: " + username
@@ -323,7 +333,7 @@ def addhubuser(hubname, username, gecos, email, pw, pwdisabled, joomlagid,
 		
 	
 	if not skipldap:
-		_add_ldap_user(username, gecos, pw, userID, homeDir, loginShell, gid, gidNumber)
+		add_ldap_user(username, gecos, pw, userID, homeDir, loginShell, gid, gidNumber)
 
 
 	# create home directory
@@ -350,11 +360,11 @@ def delhubuser(username):
 	dbPW = hubzero.config.webconfig.getWebConfigDBPassword()
 	dbUserName = hubzero.config.webconfig.getWebConfigDBUsername()
 	dbName = hubzero.config.webconfig.getWebConfigDBName()
-	db =  hubzero.data.db.mySql("localhost", dbName, dbUserName, dbPW)
+	db =  hubzero.data.db.MySQLConnection("localhost", dbName, dbUserName, dbPW)
 	
 	sql = 'select id from `jos_users` where username = %s'
 	data = (username)
-	userID = db.execSelectQueryScalar(sql, data)
+	userID = db.query_selectscalar(sql, data)
 
 	print "deleting user (" + username + ") from database"
 	
@@ -363,7 +373,7 @@ def delhubuser(username):
 	_del_jos_xprofiles(db, userID)
 	_del_jos_users(db, username)
 	
-	_delete_ldap_user(username)
+	delete_ldap_user(username)
 
 
 def updateUserPW(username, pw):
@@ -374,7 +384,7 @@ def updateUserPW(username, pw):
 	dbPW = hubzero.config.webconfig.getWebConfigDBPassword()
 	dbUserName = hubzero.config.webconfig.getWebConfigDBUsername()
 	dbName = hubzero.config.webconfig.getWebConfigDBName()
-	db =  hubzero.data.db.mySql("localhost", dbName, dbUserName, dbPW)
+	db =  hubzero.data.db.MySQLConnection("localhost", dbName, dbUserName, dbPW)
 
 	userid = _getUserID(db, username)
 	pwHash = hubzero.config.passwords.MD5PasswordHash(pw)
